# tcmb

### TODO
- [ ] Add project page to GitHub pages
- [ ] Release 0.4.0
    - [ ] Add CLI download option (csv, long/wide format)

### BACKLOG

- [ ] Add plotting module
- [ ] Consider using requests Session
- [ ] Consider adding asyncio support

### Done

- [x] Initial release
- [x] PyPI
- [x] Release 0.2.0
    - [x] Update documentation
        - [x] Add badges
        - [x] Improve method docstrings
    - [x] Mock response with fixtures 
    - [x] Accept `start` and `end` in the `YYYY-MM-DD` format as well as the `DD-MM-YYYY` format.
- [x] Release 0.3.0
    - [x] Add standalone reader that would work without creating the Client class instance
    - [x] Save categories and datagroups metadata as package data for quicker lookup
    - [x] Wildcard option for series

